unit DemoUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Buttons,
  SHELLAPI; // be sure to add SHELLAPI to this "uses" clause

type
  TFormDemo = class(TForm)
    GroupBox1: TGroupBox;
    Label1: TLabel;
    edAppToRun: TEdit;
    Label2: TLabel;
    edParams: TEdit;
    CheckBoxWait: TCheckBox;
    btnRun: TBitBtn;
    GroupBox2: TGroupBox;
    Label3: TLabel;
    edFileToPrint: TEdit;
    btnPrint: TBitBtn;
    GroupBox3: TGroupBox;
    lblLink2: TLabel;
    lblLink1: TLabel;
    procedure btnRunClick(Sender: TObject);
    procedure btnPrintClick(Sender: TObject);
    procedure lblLinkClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  FormDemo: TFormDemo;

implementation

{ Be sure to include EXECWAIT in the "uses" clause of all the units
  where you use the function ExecAppWait. }

uses
  execwait;

{$R *.DFM}

{ Click on button btnRun: launch the application that is specified in the first
  edit-box, with the parameter(s) that are specified in the second edit-box.
  If the checkbox is checked, wait for completion of the external app.
  If the external app can not be launched (for example, if it is not found),
  show an error message.
}
procedure TFormDemo.btnRunClick(Sender: TObject);
var
  Success: Boolean;
  InstanceID: THandle;
  OldCaption: string;
begin
  Success := False;

  { Use a TRY... FINALLY... construction, to ensure that the code in the
    FINALLY-part always executes, even if an error occurs in the TRY-part. }

  try
    OldCaption := Caption; // save original caption of the form

    if CheckBoxWait.Checked then begin
      { For visual feedback to the user, we hide the three groupboxes
        with all the controls, and we show a status message in the title bar
        of the form. Afterwards, when the external application has ended,
        we shall restore everything.
        Note: in order to show clearer what happens, at design time we've
        changed the form's property FormStyle to fsStayOnTop. }

      GroupBox1.Visible := False;
      GroupBox2.Visible := False;
      GroupBox3.Visible := False;
      Caption := 'Waiting for completion of: ' + edAppToRun.Text;

      { Launch external application and wait for completion.
        If no error occurs, we "stay" here, waiting for the external app
        to complete. The variable Success will receive FALSE.
        If an error occurs when launching the external app, we are returned
        immediately, without waiting. In that case, the variable Success will
        contain FALSE. }

      Success := ExecAppWait(edAppToRun.Text, edParams.Text);
    end
    else begin
      { Checkbox not checked, don't wait for completion }
      InstanceID := ShellExecute(Handle, 'open', PChar(edAppToRun.Text),
        PChar(edParams.Text), nil, SW_SHOW);
      Success := (InstanceID >= 32); // a value less than 32 is an error
    end;
  finally
    { Restore the groupboxes and the form's caption }
    GroupBox1.Visible := True;
    GroupBox2.Visible := True;
    GroupBox3.Visible := True;
    Caption := OldCaption;
    { If there was an error, show an error message }
    if not Success then
      ShowMessage('Could not run ' + edAppToRun.Text + ' ' + edParams.Text);
  end;
end;

{ Click on button btnPrint: print the file that is specified in the edit-box.
  If the file is not found, show an error message.
}
procedure TFormDemo.btnPrintClick(Sender: TObject);
var
  Success: Boolean;
  InstanceID: THandle;
begin
  Success := False;
  try
    InstanceID := ShellExecute(Handle, 'print', PChar(edFileToPrint.Text),
      nil, nil, SW_SHOW);
    Success := (InstanceID >= 32); // a value less than 32 is an error
  finally
    if not Success then
      ShowMessage('Could not print ' + edFileToPrint.Text);
  end;
end;

{ Click on label lblLink1 or lblLink2: try to open an HTML file with a given
  URL in the default browser.
  If an error occurs, show an error message.

  Tip: in the Object Inspector, we've changed the labels' property "Cursor"
  to crHandPoint. The effect of this: when you hover with the mouse over these
  labels at runtime, the cursor changes to a pointing hand. This simulates
  hyperlink behavior, as seen in a browser.
}
procedure TFormDemo.lblLinkClick(Sender: TObject);
var
  Success: Boolean;
  InstanceID: THandle;
  HTML_File: string;
begin
  if Sender = lblLink1 then
    { If first link was clicked, try to open a local HTML file.
      In this example, the file is located in the same folder as the Delphi
      program, so we extract the program's directory and add the filename. }
    HTML_File := ExtractFileDir(Application.ExeName) + '\execwait.htm'
  else
    { If the second link was clicked, try to open DelphiLand's home page }
    HTML_File := 'http://www.festra.com/';

  Success := False;
  try
    InstanceID := ShellExecute(Handle, 'open', PChar(HTML_File),
      nil, nil, SW_SHOW);
    Success := (InstanceID >= 32); // a value less than 32 is an error
  finally
    if not Success then
      ShowMessage('Could not open ' + HTML_File);
  end;
end;

end.
